@media all and (min-width : 500px) {
    @document url(http://www.w3.org/),
                   url-prefix(http://www.w3.org/Style/),
                   domain(mozilla.org),
                   regexp("https:.*")
    {
        @page :last {
            margin : 3in;
        }
    }
}
